/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

import { TestConnection } from './test-js/test_connection-proxy';
import { TestConnectionWithCloseFuture } from './test-js/test_connection_with_close_future-proxy';

/**

 @class
*/
export default class TestService {

  constructor (eb: any, address: string);

  setFloatHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  basicTypes(str: string, b: number, s: number, i: number, l: number, f: number, d: number, c: string, bool: boolean) : void;

  longDeliveryFailed(resultHandler: (err: any, result: string) => any) : void;

  noParams() : void;

  listDoubleHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  longNullHandler(resultHandler: (err: any, result: any) => any) : void;

  listDataObjectHandler(resultHandler: (err: any, result: Array<any>) => any) : void;

  stringNullHandler(resultHandler: (err: any, result: string | null) => any) : void;

  listShortHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  fluentMethod(str: string, resultHandler: (err: any, result: string) => any) : TestService;

  dataObjectNullHandler(resultHandler: (err: any, result: any | null) => any) : void;

  booleanNullHandler(resultHandler: (err: any, result: any) => any) : void;

  basicBoxedTypes(str: string, b: number, s: number, i: number, l: number, f: number, d: number, c: string, bool: boolean) : void;

  listJsonArrayHandler(resultHandler: (err: any, result: Array<Array>) => any) : void;

  listLongHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  enumTypeNull(someEnum: string | null) : void;

  enumTypeAsResult(someEnum: (err: any, result: string) => any) : void;

  setIntHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  longDeliverySuccess(resultHandler: (err: any, result: string) => any) : void;

  doubleHandler(resultHandler: (err: any, result: any) => any) : void;

  jsonTypesNull(jsonObject: Object | null, jsonArray: Array | null) : void;

  stringHandler(resultHandler: (err: any, result: string) => any) : void;

  jsonTypes(jsonObject: Object, jsonArray: Array) : void;

  setDoubleHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  invokeWithMessage(object: Object, str: string, i: number, chr: string, senum: string, resultHandler: (err: any, result: string) => any) : void;

  intNullHandler(resultHandler: (err: any, result: any) => any) : void;

  dataObjectType(options: any) : void;

  dataObjectHandler(resultHandler: (err: any, result: any) => any) : void;

  listJsonObjectHandler(resultHandler: (err: any, result: Array<Object>) => any) : void;

  jsonArrayNullHandler(resultHandler: (err: any, result: Array | null) => any) : void;

  setByteHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  setStringHandler(resultHandler: (err: any, result: Array<string>) => any) : void;

  listIntHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  shortHandler(resultHandler: (err: any, result: any) => any) : void;

  byteHandler(resultHandler: (err: any, result: any) => any) : void;

  mapParams(mapString: Object<string, string>, mapByte: Object<string, number>, mapShort: Object<string, number>, mapInt: Object<string, number>, mapLong: Object<string, number>, mapJsonObject: Object<string, Object>, mapJsonArray: Object<string, Array>) : void;

  setDataObjectHandler(resultHandler: (err: any, result: Array<any>) => any) : void;

  fluentNoParams() : TestService;

  listByteHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  intHandler(resultHandler: (err: any, result: any) => any) : void;

  enumType(someEnum: string) : void;

  jsonArrayHandler(resultHandler: (err: any, result: Array) => any) : void;

  listParams(listString: Array<string>, listByte: Array<number>, listShort: Array<number>, listInt: Array<number>, listLong: Array<number>, listJsonObject: Array<Object>, listJsonArray: Array<Array>, listDataObject: Array<any>) : void;

  charNullHandler(resultHandler: (err: any, result: any) => any) : void;

  floatNullHandler(resultHandler: (err: any, result: any) => any) : void;

  listCharHandler(resultHandler: (err: any, result: Array<string>) => any) : void;

  voidHandler(resultHandler: (err: any, result: any) => any) : void;

  floatHandler(resultHandler: (err: any, result: any) => any) : void;

  listBoolHandler(resultHandler: (err: any, result: Array<boolean>) => any) : void;

  dataObjectTypeNull(options: any | null) : void;

  booleanHandler(resultHandler: (err: any, result: any) => any) : void;

  listFloatHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  setCharHandler(resultHandler: (err: any, result: Array<string>) => any) : void;

  jsonObjectHandler(resultHandler: (err: any, result: Object) => any) : void;

  failingMethod(resultHandler: (err: any, result: Object) => any) : void;

  createConnection(str: string, resultHandler: (err: any, result: TestConnection) => any) : void;

  charHandler(resultHandler: (err: any, result: any) => any) : void;

  shortNullHandler(resultHandler: (err: any, result: any) => any) : void;

  setBoolHandler(resultHandler: (err: any, result: Array<boolean>) => any) : void;

  setJsonArrayHandler(resultHandler: (err: any, result: Array<Array>) => any) : void;

  byteNullHandler(resultHandler: (err: any, result: any) => any) : void;

  doubleNullHandler(resultHandler: (err: any, result: any) => any) : void;

  longHandler(resultHandler: (err: any, result: any) => any) : void;

  createConnectionWithCloseFuture(resultHandler: (err: any, result: TestConnectionWithCloseFuture) => any) : void;

  setJsonObjectHandler(resultHandler: (err: any, result: Array<Object>) => any) : void;

  listStringHandler(resultHandler: (err: any, result: Array<string>) => any) : void;

  jsonObjectNullHandler(resultHandler: (err: any, result: Object | null) => any) : void;

  enumTypeAsResultNull(someEnum: (err: any, result: string | null) => any) : void;

  basicBoxedTypesNull(str: string | null, b: number | null, s: number | null, i: number | null, l: number | null, f: number | null, d: number | null, c: string | null, bool: boolean | null) : void;

  setLongHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  setShortHandler(resultHandler: (err: any, result: Array<number>) => any) : void;

  setParams(setString: Array<string>, setByte: Array<number>, setShort: Array<number>, setInt: Array<number>, setLong: Array<number>, setJsonObject: Array<Object>, setJsonArray: Array<Array>, setDataObject: Array<any>) : void;
}